@@ -2,7 +2,7 @@ from DiscordUtils import Pagination
 from DiscordUtils.InviteTracker import InviteTracker
 from DiscordUtils.Music import Music
 
-__title__ = "DisUtils"
-__version__ = "1.3.6"
+__title__ = "DiscordUtils"
+__version__ = "1.3.7"
 __author__ = "DTS"
 __license__ = "MIT"
